# AutoIt

To use this language, use the class "language-autoit".

## Comments

    ; Single-line comment
    #comments-start
    	Multi-line
    	comment
    #comments-end
    #cs
    	Multi-line
    	comment
    #ce
    ;#comments-start
    	foo()
    ;#comments-end

## Strings

    "foo'bar'baz"
    "foo""bar""baz"
    'foo"bar"baz'
    'foo''bar''baz'

## Numbers

    2
    4.566
    1.5e3
    0x4fff

## Booleans

    True
    False

## Keywords and variables

    ; Display all the numbers for 1 to 10 but skip displaying  7.
    For $i = 1 To 10
        If $i = 7 Then
            ContinueLoop ; Skip displaying the message box when $i is equal to 7.
        EndIf
        MsgBox($MB_SYSTEMMODAL, "", "The value of $i is: " & $i)
    Next

## Known failures

There are certain edge cases where Prism will fail. There are always such cases in every regex-based syntax highlighter. However, Prism dares to be open and honest about them. If a failure is listed here, it doesn’t mean it will never be fixed. This is more of a “known bugs” list, just with a certain type of bug.

### Comment-like substrings

    "This string ; is broken"

### Nested block comments

    #cs
    	#cs
    		foo()
    	#ce
    #ce